#include <iostream>
#include <vector>
#include <queue>
#include <cstdlib>
//#include <cstdlib>

#define INF 20000

using namespace std;

int n=0;

struct Vertex
{
    int pred;
    int x, y;
    vector <int> neighbours;
    vector <int> weights;
    Vertex(int _x=0, int _y=0)
    {
        x = _x;
        y = _y;
    }
};

struct MyPair
{
	int a, b;
	MyPair(int _a=0, int _b=0)
	{
		a = _a;
		b = _b;
	}
};

vector <Vertex> vertices;
int *dists;
bool used[128];
int depths[128];

void ConnectTo(int aInd, int bInd)
{
    Vertex *a = &vertices[aInd],
        *b = &vertices[bInd];
    int diffx, diffy;
    diffx = abs(a->x - b->x);
    diffy = abs(a->y - b->y);
    int weight =  max(diffx, diffy);
    if(weight!=0)
	{
		a->neighbours.push_back(bInd);
		a->weights.push_back(weight);
	}
    
    //b->neighbours.push_back(aInd);
    //b->weights.push_back(weight);
}

void ConnectToAll(int vertexInd)
{
    Vertex current = vertices[vertexInd];
    for(int t=0; t<vertices.size(); t++)
    {
        Vertex target = vertices[t];
        ConnectTo(vertexInd, t);
    }
}

void ShowAllConnections(int vertexInd)
{
    for(int i=0; i<vertices[vertexInd].neighbours.size(); i++)
    {
        //cout<<vertices[vertexInd].neighbours[i]<<"->"<<vertices[vertexInd].weights[i]<<" ";
    }
}

MyPair ClosestPairInd(vector <int> froms)
{
	int minLen = INF;
	int minPairAInd=0, minPairBInd=0;
	for(int curInd=0; curInd<froms.size(); curInd++)
	{
		Vertex current = vertices[froms[curInd]];
		//cout<<"\n--"<<froms[curInd]<<endl;
		for(int k=0; k<current.neighbours.size(); k++)
		{
			int curNeighbInd = current.neighbours[k];
			if(!used[curNeighbInd] && (dists[curNeighbInd] == INF || (dists[curNeighbInd] >= dists[froms[curInd]] + current.weights[k]) && depths[curNeighbInd] < depths[froms[curInd]]+1))
			{
				dists[curNeighbInd] = dists[froms[curInd]] + current.weights[k];
				//cout<<"---"<<endl;
				if(dists[curNeighbInd] <= minLen)
				{
					depths[curNeighbInd] = depths[froms[curInd]]+1;
					minLen = dists[curNeighbInd];
					//cout<<"minLen: "<<minLen<<endl;
					minPairAInd = froms[curInd];
					minPairBInd = curNeighbInd;
				}
			}
		}
	}

	return MyPair(minPairAInd, minPairBInd);
}

int Dijkstra(int start)
{
	vector <int> toVisit;
	toVisit.push_back(start);
	dists[start] = 0;
	used[start] = true;
	int depth = 0;

	while(!toVisit.empty())
	{
		MyPair visitPair = ClosestPairInd(toVisit);
		vector<int>::iterator destroy;
		
		toVisit.push_back(visitPair.b);
		used[visitPair.a] = true;
		depth++;

		for(int i=1; i<2*n+1; i++)
		{
			if(depths[i] == n)
				return dists[i];
		}
		if(depth == n)
		{
			//return dists[visitPair.b];
		}
	}
	return INF/2;
}

int main()
{
    
    cin>>n;
    vertices.resize(2*n+1);
	vertices[0] = Vertex(0,0);
	dists = new int[2*n+1];
	for(int i=0; i<2*n+1; i++)
	{
		dists[i] = INF;
	}

    for(int i=0; i<2*n; i++)
    {
        int x,y;
        cin>>x>>y;
        vertices[i+1] = Vertex(x, y);
    }
    
    for(int i=0; i<2*n+1; i++)
    {
        ConnectToAll(i);
    }
    
    for(int i=0; i<2*n+1; i++)
    {
        //cout<<i<<": ";
        ShowAllConnections(i);
        //cout<<endl;
    }

	int minLenght = Dijkstra(0);

	cout<<minLenght<<endl;
    
    return 0;
}