#include <cstdio>
#include <algorithm>
#include <vector>
#include <cmath>

using namespace std;

const int N = 1024;

struct Point
{
	int x, y;

	Point() {}

	Point(int _x, int _y)
	{
		x = _x;
		y = _y;
	}

	void Print() const
	{
		printf("%d %d", x, y);
	}
};

struct Line
{
	Point A, B;

	void Print() const
	{
		A.Print();
		printf(" ");
		B.Print();
		printf("\n");
	}
};

Line l[N];
int n, cnt;
bool crossed[N];
vector <int> g[N];

void Input()
{
	int a, b, c, d;
	
	while (scanf("%d%d%d%d", &a, &b, &c, &d) != EOF)
	{
		l[n].A = Point(a, b);
		l[n].B = Point(c, d);
		n++;
	}
}

void Output()
{
	for (int i = 0; i < n; i++) l[i].Print();
}

Point CreateVector(Point P, Point Q)
{
	return Point(Q.x - P.x, Q.y - P.y);
}

double CrossProduct(Point P, Point Q)
{
	return P.x * Q.y - P.y * Q.x;
}

double LineSize(Point P, Point Q)
{
	return sqrt((Q.x - P.x) * (Q.x - P.x) + (Q.y - P.y) * (Q.y - P.y));
}

bool IsCross(Line T, Line P)
{
	Point V1 = CreateVector(T.A, T.B);
	Point V2 = CreateVector(T.A, P.A);

	double cp1 = CrossProduct(V1, V2);
	
	V2 = CreateVector(T.A, P.B);
	
	double cp2 = CrossProduct(V1, V2);

	if (cp1 * cp2 > 0) return false;

	V1 = CreateVector(P.A, P.B);
	V2 = CreateVector(P.A, T.A);

	cp1 = CrossProduct(V1, V2);

	V2 = CreateVector(P.A, T.B);
	cp2 = CrossProduct(V1, V2);

	if (cp1 * cp2 > 0) return false;
	if (!cp1 && !cp2)
	{
		double s1 = LineSize(T.A, T.B);
		double s2 = LineSize(T.A, P.A);
		double s3 = LineSize(T.A, P.B);
		double s4 = LineSize(T.B, P.A);
		double s5 = LineSize(T.B, P.B);

		if ((s1 >= s2 && s1 >= s4) || (s1 >= s3 && s1 >= s5)) return true;

		return false;
	}

	return true;
}

void DFS(int i)
{
	crossed[i] = 1;
	cnt++;

	for (int j = 0; j < g[i].size(); j++)
		if (!crossed[g[i][j]]) DFS(g[i][j]);
}

void Solve()
{
	swap(l[0], l[n - 1]);//l[0] provodnik !

	int i, j;

	for (i = 0; i < n - 1; i++)
		for (j = i + 1; j < n; j++)
			if (IsCross(l[i], l[j]))
			{
				g[i].push_back(j);
				g[j].push_back(i);

				//printf("%d %d\n", i, j);
			}
	DFS(0);

	printf("%d\n", n - cnt);
	//Output();
}

int main()
{
	Input();
	//Output();
	Solve();
	
	return 0;
}